@@ -88,6 +88,7 @@ public:
 		: QTextEdit(document)
 		, m_document(document)
 	{
+		setAutoFillBackground(false);
 	}
 
 protected:
@@ -929,15 +930,16 @@ void Document::loadTheme(const Theme& theme)
 	m_text->document()->blockSignals(true);
 
 	// Update colors
-	m_text->setStyleSheet(theme.styleSheet());
-
 	m_text_color = theme.textColor();
 	m_text_color.setAlpha(255);
 	QColor text_color = m_text_color;
 	text_color.setAlpha(m_focus_mode ? 128 : 255);
 
 	QPalette p = m_text->palette();
+	p.setBrush(QPalette::Base, Qt::transparent);
 	p.setColor(QPalette::Text, text_color);
+	p.setColor(QPalette::Highlight, m_text_color);
+	p.setColor(QPalette::HighlightedText, (qGray(m_text_color.rgb()) > 127) ? Qt::black : Qt::white);
 	m_text->setPalette(p);
 
 	m_highlighter->setMisspelledColor(theme.misspelledColor());
