@@ -1,33 +1,20 @@
-/***********************************************************************
- *
- * Copyright (C) 2010, 2011, 2012, 2013, 2014 Graeme Gott <graeme@gottcode.org>
- *
- * Derived in part from KWord's rtfimport.cpp
- *  Copyright (C) 2001 Ewald Snel <ewald@rambo.its.tudelft.nl>
- *  Copyright (C) 2001 Tomasz Grobelny <grotk@poczta.onet.pl>
- *  Copyright (C) 2003, 2004 Nicolas GOUTTE <goutte@kde.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2010-2022 Graeme Gott <graeme@gottcode.org>
+	SPDX-FileCopyrightText: 2001 Ewald Snel <ewald@rambo.its.tudelft.nl>
+	SPDX-FileCopyrightText: 2001 Tomasz Grobelny <grotk@poczta.onet.pl>
+	SPDX-FileCopyrightText: 2003, 2004 Nicolas GOUTTE <goutte@kde.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+
+	Derived in part from KWord's rtfimport.cpp
+*/
 
 #include "rtf_reader.h"
 
+#include "text_codec.h"
+
 #include <QFile>
 #include <QTextBlock>
-#include <QTextCodec>
-#include <QTextDecoder>
 
 #include <cmath>
 
@@ -35,24 +22,54 @@
 
 namespace
 {
-	QTextCodec* codecForCodePage(qint32 value, QByteArray* codepage = 0)
-	{
-		QByteArray name = "CP" + QByteArray::number(value);
-		QByteArray codec;
-		if (value == 932) {
-			codec = "Shift-JIS";
-		} else if (value == 10000) {
-			codec = "Apple Roman";
-		} else if (value == 65001) {
-			codec = "UTF-8";
-		} else {
-			codec = name;
-		}
-		if (codepage) {
-			*codepage = name;
-		}
-		return QTextCodec::codecForName(codec);
+
+TextCodec* codecForCodePage(qint32 value)
+{
+	TextCodec* codec = nullptr;
+
+	// Look up by ISO codec
+	switch (value) {
+	case   819: codec = TextCodec::codecForName("ISO-8859-1"); break;
+	case  1200: codec = TextCodec::codecForName("UTF-16LE"); break;
+	case  1201: codec = TextCodec::codecForName("UTF-16BE"); break;
+	case 12000: codec = TextCodec::codecForName("UTF-32LE"); break;
+	case 12001: codec = TextCodec::codecForName("UTF-32BE"); break;
+	case 65001: codec = TextCodec::codecForName("UTF-8"); break;
 	}
+	if (codec) {
+		return codec;
+	}
+
+	// Look up by codepage number
+	codec = TextCodec::codecForName("CP" + QByteArray::number(value));
+	if (codec) {
+		return codec;
+	}
+
+	// Look up by fallback codec name
+	switch (value) {
+	case   708: codec = TextCodec::codecForName("ASMO-708"); break;
+	case 10000: codec = TextCodec::codecForName("MACINTOSH"); break;
+	case 10001: codec = TextCodec::codecForName("SJIS"); break;
+	case 10002: codec = TextCodec::codecForName("BIG5"); break;
+	case 10003: codec = TextCodec::codecForName("JOHAB"); break;
+	case 10004: codec = TextCodec::codecForName("MACARABIC"); break;
+	case 10005: codec = TextCodec::codecForName("MACHEBREW"); break;
+	case 10006: codec = TextCodec::codecForName("MACGREEK"); break;
+	case 10007: codec = TextCodec::codecForName("MACCYRILLIC"); break;
+	case 10008: codec = TextCodec::codecForName("GB2312"); break;
+	case 10010: codec = TextCodec::codecForName("MACROMANIA"); break;
+	case 10017: codec = TextCodec::codecForName("MACUKRAINE"); break;
+	case 10021: codec = TextCodec::codecForName("MACTHAI"); break;
+	case 10029: codec = TextCodec::codecForName("MACCENTRALEUROPE"); break;
+	case 10079: codec = TextCodec::codecForName("MACICELAND"); break;
+	case 10081: codec = TextCodec::codecForName("MACTURKISH"); break;
+	case 10082: codec = TextCodec::codecForName("MACCROATIAN"); break;
+	}
+
+	return codec;
+}
+
 }
 
 //-----------------------------------------------------------------------------
@@ -60,9 +77,9 @@ namespace
 class RtfReader::FunctionTable
 {
 public:
-	FunctionTable() :
-		m_group_end_func(0),
-		m_insert_text_func(0)
+	explicit FunctionTable()
+		: m_group_end_func(nullptr)
+		, m_insert_text_func(nullptr)
 	{
 	}
 
@@ -120,9 +137,9 @@ private:
 	class Function
 	{
 	public:
-		Function(void (RtfReader::*func)(qint32) = 0, qint32 value = 0) :
-			m_func(func),
-			m_value(value)
+		explicit Function(void (RtfReader::*func)(qint32) = nullptr, qint32 value = 0)
+			: m_func(func)
+			, m_value(value)
 		{
 		}
 
@@ -143,10 +160,9 @@ heading_functions;
 
 //-----------------------------------------------------------------------------
 
-RtfReader::RtfReader() :
-	m_in_block(true),
-	m_codec(0),
-	m_decoder(0)
+RtfReader::RtfReader()
+	: m_in_block(true)
+	, m_codec(nullptr)
 {
 	if (functions.isEmpty()) {
 		functions.setInsertText(&RtfReader::insertText);
@@ -295,13 +311,6 @@ RtfReader::RtfReader() :
 
 //-----------------------------------------------------------------------------
 
-RtfReader::~RtfReader()
-{
-	delete m_decoder;
-}
-
-//-----------------------------------------------------------------------------
-
 bool RtfReader::canRead(QIODevice* device)
 {
 	return device->peek(5) == "{\\rtf";
@@ -352,7 +361,7 @@ void RtfReader::readData(QIODevice* device)
 				}
 			} else if (m_token.type() == TextToken) {
 				if (!m_state.ignore_text) {
-					m_state.functions->insertText(this, m_decoder->toUnicode(m_token.text()));
+					m_state.functions->insertText(this, m_codec->toUnicode(m_token.text()));
 				}
 			}
 		}
@@ -388,7 +397,7 @@ void RtfReader::ignoreText(qint32)
 
 void RtfReader::insertHexSymbol(qint32)
 {
-	m_cursor.insertText(m_decoder->toUnicode(m_token.hex()));
+	m_cursor.insertText(m_codec->toUnicode(m_token.hex()));
 }
 
 //-----------------------------------------------------------------------------
@@ -409,18 +418,19 @@ void RtfReader::insertText(const QString& text)
 
 void RtfReader::insertUnicodeSymbol(qint32 value)
 {
-	if (value)
-	{
+	if (value > 0) {
 		m_cursor.insertText(QChar(value));
+	} else if (value < 0) {
+		m_cursor.insertText(QChar(value + 0x10000));
 	}
 
 	for (int i = m_state.skip; i > 0;) {
 		m_token.readNext();
 
 		if (m_token.type() == TextToken) {
-			int len = m_token.text().count();
+			const int len = m_token.text().length();
 			if (len > i) {
-				m_cursor.insertText(m_decoder->toUnicode(m_token.text().mid(i)));
+				m_cursor.insertText(m_codec->toUnicode(m_token.text().mid(i)));
 				break;
 			} else {
 				i -= len;
@@ -552,12 +562,10 @@ void RtfReader::setSkipCharacters(qint32 value)
 
 void RtfReader::setCodepage(qint32 value)
 {
-	QByteArray codepage;
-	QTextCodec* codec = codecForCodePage(value, &codepage);
-	if (codec != 0) {
+	TextCodec* codec = codecForCodePage(value);
+	if (codec) {
 		m_codepage = codec;
-		m_encoding = codepage;
-		setCodec(codec);
+		m_codec = codec;
 	}
 }
 
@@ -568,14 +576,14 @@ void RtfReader::setFont(qint32 value)
 	m_state.active_codepage = value;
 
 	if (value < m_codepages.count()) {
-		setCodec(m_codepages[value]);
+		m_codec = m_codepages[value];
 	} else {
-		setCodec(0);
+		m_codec = nullptr;
 		m_codepages.resize(value + 1);
 	}
 
-	if (m_codec == 0) {
-		setCodec(m_codepage);
+	if (!m_codec) {
+		m_codec = m_codepage;
 	}
 }
 
@@ -589,10 +597,10 @@ void RtfReader::setFontCodepage(qint32 value)
 		return;
 	}
 
-	QTextCodec* codec = codecForCodePage(value);
-	if (codec != 0) {
+	TextCodec* codec = codecForCodePage(value);
+	if (codec) {
 		m_codepages[m_state.active_codepage] = codec;
-		setCodec(codec);
+		m_codec = codec;
 	}
 	m_state.ignore_control_word = true;
 	m_state.ignore_text = true;
@@ -607,58 +615,57 @@ void RtfReader::setFontCharset(qint32 value)
 		return;
 	}
 
-	if (m_codepages[m_state.active_codepage] != 0) {
-		setCodec(m_codepages[m_state.active_codepage]);
+	if (m_codepages[m_state.active_codepage]) {
+		m_codec = m_codepages[m_state.active_codepage];
 		m_state.ignore_text = true;
 		return;
 	}
 
-	QByteArray charset;
+	qint32 charset;
 	switch (value) {
-	case 0: charset = "CP1252"; break;
-	case 1: charset = "CP1252"; break;
-	case 77: charset = "Apple Roman"; break;
-	case 128: charset = "Shift-JIS"; break;
-	case 129: charset = "eucKR"; break;
-	case 130: charset = "CP1361"; break;
-	case 134: charset = "GB2312"; break;
-	case 136: charset = "Big5-HKSCS"; break;
-	case 161: charset = "CP1253"; break;
-	case 162: charset = "CP1254"; break;
-	case 163: charset = "CP1258"; break;
-	case 177: charset = "CP1255"; break;
-	case 178: charset = "CP1256"; break;
-	case 186: charset = "CP1257"; break;
-	case 204: charset = "CP1251"; break;
-	case 222: charset = "CP874"; break;
-	case 238: charset = "CP1250"; break;
-	case 255: charset = "CP850"; break;
+	case   0: charset = 1252; break;
+	case   1: charset = 1252; break;
+	case  77: charset = 10000; break;
+	case  78: charset = 10001; break;
+	case  79: charset = 10003; break;
+	case  80: charset = 10008; break;
+	case  81: charset = 10002; break;
+	case  83: charset = 10005; break;
+	case  84: charset = 10004; break;
+	case  85: charset = 10006; break;
+	case  86: charset = 10081; break;
+	case  87: charset = 10021; break;
+	case  88: charset = 10029; break;
+	case  89: charset = 10007; break;
+	case 128: charset = 932; break;
+	case 129: charset = 949; break;
+	case 130: charset = 1361; break;
+	case 134: charset = 936; break;
+	case 136: charset = 950; break;
+	case 161: charset = 1253; break;
+	case 162: charset = 1254; break;
+	case 163: charset = 1258; break;
+	case 177: charset = 1255; break;
+	case 178: charset = 1256; break;
+	case 186: charset = 1257; break;
+	case 204: charset = 1251; break;
+	case 222: charset = 874; break;
+	case 238: charset = 1250; break;
+	case 254: charset = 437; break;
+	case 255: charset = 850; break;
 	default: return;
 	}
 
-	QTextCodec* codec = QTextCodec::codecForName(charset);
-	if (codec != 0) {
+	TextCodec* codec = codecForCodePage(charset);
+	if (codec) {
 		m_codepages[m_state.active_codepage] = codec;
-		setCodec(codec);
+		m_codec = codec;
 	}
 	m_state.ignore_text = true;
 }
 
 //-----------------------------------------------------------------------------
 
-void RtfReader::setCodec(QTextCodec* codec)
-{
-	if (m_codec != codec) {
-		m_codec = codec;
-		if (m_codec) {
-			delete m_decoder;
-			m_decoder = m_codec->makeDecoder();
-		}
-	}
-}
-
-//-----------------------------------------------------------------------------
-
 void RtfReader::setOutlineLevel(qint32 value)
 {
 	m_state.block_format.setProperty(QTextFormat::UserProperty, qBound(1, value + 1, 6));
@@ -671,8 +678,8 @@ void RtfReader::setStyle(qint32 value)
 {
 	m_state.style = value;
 
-	QHash<int, Style>::const_iterator style = m_styles.find(m_state.style);
-	if (style != m_styles.end()) {
+	QHash<int, Style>::const_iterator style = m_styles.constFind(m_state.style);
+	if (style != m_styles.constEnd()) {
 		m_state.block_format.merge(style->block_format);
 		m_cursor.mergeBlockFormat(m_state.block_format);
 
@@ -764,7 +771,7 @@ void RtfReader::setStyleEnd()
 
 void RtfReader::setStyleSheetEnd()
 {
-	stylesheet_functions.setGroupEnd(0);
+	stylesheet_functions.setGroupEnd(nullptr);
 }
 
 //-----------------------------------------------------------------------------
